@@ -2,6 +2,7 @@ from distillation.utils import *
 from fastai.vision.all import *
 import fastai
 import torchvision.models as models
+import shutil
 
 
 def pureDistillation(baseModel, targetModel, path, pathUnlabelled, outputPath, bs=32, size=224, confidence=0.8):
@@ -25,7 +26,8 @@ def pureDistillation(baseModel, targetModel, path, pathUnlabelled, outputPath, b
 
         # Train base learner
         learn.fine_tune(50, freeze_epochs=2)
-        learn.export(fname=outputPath+os.sep+baseModel+'.pkl')
+        learn.save(baseModel)
+        shutil.copy(path+os.sep+'models'+os.sep+'model-'+baseModel+'.pth',outputPath)
 
         # supervised method
         plainSupervised(path,pathUnlabelled,learn,confidence)
@@ -43,7 +45,8 @@ def pureDistillation(baseModel, targetModel, path, pathUnlabelled, outputPath, b
 
         # Train base learner
         learn2.fine_tune(50, freeze_epochs=2)
-        learn2.export(fname=outputPath+os.sep+targetModel+'.pkl')
+        learn2.save(outputPath+os.sep+targetModel)
+        shutil.copy(path+os.sep+'models' + os.sep + 'model-' + targetModel + '.pth', outputPath)
         shutil.rmtree(path+'_tmp')
 
 
